# Table of Contents

- [previewing-templates-and-creating-diagrams-from-templates](<./previewing-templates-and-creating-diagrams-from-templates.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Previewing Templates and Creating Diagrams from Templates](<./Previewing-Templates-and-Creating-Diagrams-from-Templates.md>)
  - [Overview](<./Previewing-Templates-and-Creating-Diagrams-from-Templates/Overview.md>)
  - [Limitations](<./Previewing-Templates-and-Creating-Diagrams-from-Templates/Limitations.md>)
  - [Previewing Diagram Templates](<./Previewing-Templates-and-Creating-Diagrams-from-Templates/Previewing-Diagram-Templates.md>)
  - [Sharing Template Previews by URL](<./Previewing-Templates-and-Creating-Diagrams-from-Templates/Sharing-Template-Previews-by-URL.md>)
  - [Creating a Free Draw Diagram from a Template Preview](<./Previewing-Templates-and-Creating-Diagrams-from-Templates/Creating-a-Free-Draw-Diagram-from-a-Template-Preview.md>)
  - [Was this page helpful?](<./Previewing-Templates-and-Creating-Diagrams-from-Templates/Was-this-page-helpful.md>)
